==> antlr-java-parser-1.0.2-sources.jar: com/github/antlrjavaparser/adapter/ElementValuePairContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.Node;
import com.github.antlrjavaparser.api.expr.MemberValuePair;

public class ElementValuePairContextAdapter implements Adapter<MemberValuePair, Java7Parser.ElementValuePairContext> {
    public MemberValuePair adapt(Java7Parser.ElementValuePairContext context) {

        /*
        elementValuePair
        :   Identifier EQ elementValue
        ;
        */

        MemberValuePair memberValuePair = new MemberValuePair();
        memberValuePair.setName(context.Identifier().getText());
        memberValuePair.setValue(Adapters.getElementValueContextAdapter().adapt(context.elementValue()));

        return memberValuePair;
    }
}

==> antlr-java-parser-1.0.9-sources.jar: com/github/antlrjavaparser/adapter/ElementValuePairContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.Node;
import com.github.antlrjavaparser.api.expr.MemberValuePair;

public class ElementValuePairContextAdapter implements Adapter<MemberValuePair, Java7Parser.ElementValuePairContext> {
    public MemberValuePair adapt(Java7Parser.ElementValuePairContext context, AdapterParameters adapterParameters) {

        /*
        elementValuePair
        :   Identifier EQ elementValue
        ;
        */

        MemberValuePair memberValuePair = new MemberValuePair();
        AdapterUtil.setComments(memberValuePair, context, adapterParameters);
        memberValuePair.setName(context.Identifier().getText());
        memberValuePair.setValue(Adapters.getElementValueContextAdapter().adapt(context.elementValue(), adapterParameters));

        return memberValuePair;
    }
}
